<?php

declare(strict_types=1);

namespace Drupal\fz152_contact;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;

/**
 * Common service.
 */
final class Fz152ContactService {

  /**
   * Constructs a Fz152ContactService object.
   */
  public function __construct(
    protected readonly ConfigFactoryInterface $config,
    protected readonly EntityTypeBundleInfoInterface $bundleInfo,
  ) {}

  /**
   * Returns a list of contact forms.
   *
   * @return array
   *   A keyed array of contact forms.
   *
   * @see \Drupal\Core\Entity\EntityTypeBundleInfoInterface::getBundleInfo()
   */
  protected function getContactForms() {
    return $this->bundleInfo->getBundleInfo('contact_message');
  }

  /**
   * {@inheritdoc}
   */
  public function getForms() {
    $forms = [];
    $contact_forms = $this->getContactForms();
    foreach (array_keys($contact_forms) as $form) {
      $config = $this->config->get("fz152_contact.settings.$form");
      if ($config->get('enabled')) {
        $forms[] = [
          'form_id' => 'contact_message_' . $form . '_form',
          'weight' => $config->get('weight') ?: NULL,
          'checkbox_title' => $config->get('checkbox_title') ?? NULL,
        ];
      }
    }
    return $forms;
  }

}
