<?php

declare(strict_types=1);

namespace Drupal\fz152_consent\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * Defines the fz152 consent entity class.
 *
 * @ContentEntityType(
 *   id = "fz152_consent",
 *   label = @Translation("FZ152 Consent"),
 *   label_collection = @Translation("FZ152 Consents"),
 *   label_singular = @Translation("fz152 consent"),
 *   label_plural = @Translation("fz152 consents"),
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "id",
 *     "uuid" = "uuid"
 *   },
 *   handlers = {
 *     "views_data" = "Drupal\views\EntityViewsData",
 *     "form" = {
 *       "delete" = "Drupal\Core\Entity\ContentEntityDeleteForm",
 *       "delete-multiple-confirm" = "Drupal\Core\Entity\Form\DeleteMultipleForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\fz152_consent\Routing\FZ152ConsentHtmlRouteProvider"
 *     }
 *   },
 *   links = {
 *     "delete-form" = "/fz152-consent/{fz152_consent}/delete",
 *     "delete-multiple-form" = "/admin/content/fz152-consent/delete-multiple"
 *   },
 *   admin_permission = "administer fz152_consent",
 *   base_table = "fz152_consent",
 *   label_count = {
 *     "singular" = "@count fz152 consents",
 *     "plural" = "@count fz152 consents"
 *   }
 * )
 */
class FZ152Consent extends ContentEntityBase {

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the fz152 consent was created.'))
      ->setDisplayConfigurable('form', FALSE)
      ->setDisplayConfigurable('view', FALSE);

    $fields['ip'] = BaseFieldDefinition::create('string')
      ->setLabel(t('IP address'))
      ->setDisplayConfigurable('form', FALSE)
      ->setDisplayConfigurable('view', FALSE);

    $fields['form_id'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Form ID'))
      ->setDisplayConfigurable('form', FALSE)
      ->setDisplayConfigurable('view', FALSE);

    $fields['source'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Source'))
      ->setDescription(t('Name, email, phone, etc'))
      ->setDisplayConfigurable('form', FALSE)
      ->setDisplayConfigurable('view', FALSE);

    return $fields;
  }

}
