<?php

namespace Drupal\fz152\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RouteBuilderInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure example settings for this site.
 */
class Fz152Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    TypedConfigManagerInterface $typedConfigManager,
    protected readonly RouteBuilderInterface $routeBuilder,
  ) {
    parent::__construct($config_factory, $typedConfigManager);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed'),
      $container->get('router.builder'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'fz152_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'fz152.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('fz152.settings');
    $form['enable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable functionality'),
      '#description' => $this->t('You can disable this functionality for different languages.'),
      '#default_value' => $config->get('enable') ?? TRUE,
    ];
    $form['is_checkbox'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show with checkbox'),
      '#description' => $this->t('If checked, text will be printed in form with checkbox.'),
      '#default_value' => $config->get('is_checkbox') ?? TRUE,
    ];
    $form['checkbox_title'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Checkbox title (default)'),
      '#default_value' => $config->get('checkbox_title') ?? '',
      '#required' => TRUE,
    ];
    for ($i = 2; $i <= 10; $i++) {
      $form["checkbox_title_$i"] = [
        '#type' => 'textarea',
        '#title' => $this->t('Checkbox title') . ' ' . $i,
        '#default_value' => $config->get("checkbox_title_$i") ?? '',
      ];
    }
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('fz152.settings')
      ->set('enable', $form_state->getValue('enable'))
      ->set('is_checkbox', $form_state->getValue('is_checkbox'))
      ->set('checkbox_title', $form_state->getValue('checkbox_title'))
      ->set('checkbox_title_2', $form_state->getValue('checkbox_title_2'))
      ->set('checkbox_title_3', $form_state->getValue('checkbox_title_3'))
      ->set('checkbox_title_4', $form_state->getValue('checkbox_title_4'))
      ->set('checkbox_title_5', $form_state->getValue('checkbox_title_5'))
      ->set('checkbox_title_6', $form_state->getValue('checkbox_title_6'))
      ->set('checkbox_title_7', $form_state->getValue('checkbox_title_7'))
      ->set('checkbox_title_8', $form_state->getValue('checkbox_title_8'))
      ->set('checkbox_title_9', $form_state->getValue('checkbox_title_9'))
      ->set('checkbox_title_10', $form_state->getValue('checkbox_title_10'))
      ->save();

    // Rebuilding the menu router cache to register routes for settings forms.
    $this->routeBuilder->rebuild();
    $this->messenger()->addStatus($this->t('Menu router cache data rebuild.'));

    parent::submitForm($form, $form_state);
  }

}
