<?php

declare(strict_types=1);

namespace Drupal\fz152;

use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Common service.
 */
final class Fz152Service {

  /**
   * Constructs a Fz152Service object.
   */
  public function __construct(
    private readonly ConfigFactoryInterface $config,
  ) {}

  /**
   * Get forms.
   */
  public function getForms() {
    $config = $this->config->get('fz152.forms');
    $forms_settings = $config->get('forms');
    $forms = [];
    if (!empty($forms_settings)) {
      foreach (explode(PHP_EOL, $forms_settings) as $form_id) {
        $form_id_exploded = explode('|', $form_id);
        $forms[] = [
          'form_id' => $form_id_exploded[0],
          'weight' => $form_id_exploded[1] ?? NULL,
          'checkbox_title' => $form_id_exploded[2] ?? NULL,
        ];
      }
    }
    return $forms;
  }

  /**
   * Check is provided form id is match any of patterns.
   */
  public function formIdMatches($form_id, $patterns) {
    // Replace new lines by "|" and wildcard by ".*".
    $to_replace = [
      // Newlines.
      '/(\r\n?|\n)/',
      // Asterisks.
      '/\\\\\*/',
    ];

    $replacements = [
      '|',
      '.*',
    ];

    $patterns_quoted = preg_quote($patterns, '/');
    $pattern = '/^(' . preg_replace($to_replace, $replacements, $patterns_quoted) . ')$/';
    preg_match($pattern, $form_id, $matches);
    return $matches;
  }

}
