<?php

declare(strict_types=1);

namespace Drupal\Tests\fz152\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests for the fz152 module.
 */
class Fz152ConsentsTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'fz152',
    'fz152_contact',
    'contact_test',
    'fz152_custom_form',
    'fz152_consent',
    'webform',
  ];

  /**
   * The User used for the test.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->adminUser = $this->DrupalCreateUser([
      'administer fz152',
      'access content',
      'access site-wide contact form',
      'administer fz152_consent',
      'access webform overview',
      'administer webform',
    ]);
  }

  /**
   * Tests consents.
   */
  public function testConsents(): void {
    $this->drupalLogin($this->adminUser);

    $this->drupalGet('/admin/config/system/fz152/forms');
    $edit = [
      'forms' => 'custom_example_form',
    ];
    $this->submitForm($edit, 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');
    $this->drupalGet('/custom/example');
    $edit = [
      'name' => 'Test',
      'message' => 'Test message',
      'fz152_agreement' => TRUE,
    ];
    $this->submitForm($edit, 'Send');
    $this->drupalGet('/admin/config/system/fz152/consents');
    $this->assertSession()->pageTextContains('custom_example_form');

    $this->drupalGet('/admin/config/system/fz152/contact');
    $edit = [
      'contact_feedback_enable' => 1,
    ];
    $this->submitForm($edit, 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');
    $this->drupalGet('/contact/feedback');
    $edit = [
      'subject[0][value]' => 'Test subject',
      'message[0][value]' => 'Test message',
      'fz152_agreement' => TRUE,
    ];
    $this->submitForm($edit, 'Send');
    $this->drupalGet('/admin/config/system/fz152/consents');
    $this->assertSession()->pageTextContains('custom_example_form');
    $this->assertSession()->pageTextContains('contact_message_feedback_form');

    $this->drupalGet('/admin/config/system/fz152/forms');
    $edit = [
      'forms' => 'webform_submission_contact_add_form',
    ];
    $this->submitForm($edit, 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');
    $this->drupalGet('/webform/contact');
    $edit = [
      'subject' => 'Test subject',
      'message' => 'Test message',
      'fz152_agreement' => TRUE,
    ];
    $this->submitForm($edit, 'Send');
    $this->drupalGet('/admin/config/system/fz152/consents');
    $this->assertSession()->pageTextContains('custom_example_form');
    $this->assertSession()->pageTextContains('contact_message_feedback_form');
    $this->assertSession()->pageTextContains('webform_submission_contact_add_form');
  }

}
