<?php

declare(strict_types=1);

namespace Drupal\Tests\fz152\Functional;

// cspell:ignore ЦЕЛЬ
use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests for the fz152 module.
 */
class Fz152ContactFormCheckboxTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'fz152',
    'fz152_contact',
    'contact_test',
  ];

  /**
   * The User used for the test.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * Settings form url.
   */
  protected Url $settingsRoute;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->settingsRoute = Url::fromUserInput('/admin/config/system/fz152/contact');
    $this->adminUser = $this->DrupalCreateUser([
      'administer fz152',
      'access content',
      'access site-wide contact form',
    ]);
  }

  /**
   * Tests contact form.
   */
  public function testContactForm1(): void {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet('/contact/feedback');
    $this->assertSession()->pageTextNotContains('ЦЕЛЬ 1');

    $this->drupalGet($this->settingsRoute);
    $this->assertSession()->statusCodeEquals(200);
    $edit = [
      'contact_feedback_enable' => 1,
    ];
    $this->submitForm($edit, 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $this->drupalGet('/contact/feedback');
    $this->assertSession()->pageTextContains('ЦЕЛЬ 1');
  }

  /**
   * Tests contact form.
   */
  public function testContactForm2(): void {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet('/contact/feedback');
    $this->assertSession()->pageTextNotContains('ЦЕЛЬ 2');

    $this->drupalGet($this->settingsRoute);
    $this->assertSession()->statusCodeEquals(200);
    $edit = [
      'contact_feedback_enable' => 1,
      'contact_feedback_checkbox_title' => 2,
    ];
    $this->submitForm($edit, 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $this->drupalGet('/contact/feedback');
    $this->assertSession()->pageTextContains('ЦЕЛЬ 2');
  }

}
