<?php

declare(strict_types=1);

namespace Drupal\Tests\fz152\Functional;

// cspell:ignore ЦЕЛЬ
use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests for the fz152 module.
 */
class Fz152CustomFormCheckboxTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'fz152',
    'fz152_custom_form',
  ];

  /**
   * The User used for the test.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * Settings form url.
   */
  protected Url $settingsRoute;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->settingsRoute = Url::fromUserInput('/admin/config/system/fz152/forms');
    $this->adminUser = $this->DrupalCreateUser([
      'administer fz152',
      'access content',
    ]);
  }

  /**
   * Tests custom form.
   */
  public function testCustomForm1(): void {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet('/custom/example');
    $this->assertSession()->pageTextNotContains('ЦЕЛЬ 1');

    $this->drupalGet($this->settingsRoute);
    $this->assertSession()->statusCodeEquals(200);
    $edit = [
      'forms' => 'custom_example_form',
    ];
    $this->submitForm($edit, 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $this->drupalGet('/custom/example');
    $this->assertSession()->pageTextContains('ЦЕЛЬ 1');
  }

  /**
   * Tests custom form.
   */
  public function testCustomForm2(): void {
    $this->drupalLogin($this->adminUser);
    $this->drupalGet('/custom/example');
    $this->assertSession()->pageTextNotContains('ЦЕЛЬ 2');

    $this->drupalGet($this->settingsRoute);
    $this->assertSession()->statusCodeEquals(200);
    $edit = [
      'forms' => 'custom_example_form||2',
    ];
    $this->submitForm($edit, 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $this->drupalGet('/custom/example');
    $this->assertSession()->pageTextContains('ЦЕЛЬ 2');
  }

}
