<?php

declare(strict_types=1);

namespace Drupal\Tests\fz152\Functional;

// cspell:ignore Настоящие Положение является официальным документом
use Drupal\Core\Url;
use Drupal\filter\Entity\FilterFormat;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests for the fz152 module.
 */
class Fz152PrivacyPageControllerTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'fz152',
  ];

  /**
   * The User used for the test.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $user;

  /**
   * Settings form url.
   */
  protected Url $pageRoute;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->pageRoute = Url::fromRoute('fz152.privacy_policy_page');
    $basic_html_format = FilterFormat::create([
      'format' => 'basic_html',
      'name' => 'Basic HTML',
      'filters' => [
        'filter_html' => [
          'status' => 1,
          'settings' => [
            'allowed_html' => '<p> <br> <strong> <a> <em>',
          ],
        ],
      ],
    ]);
    $basic_html_format->save();
    $this->user = $this->DrupalCreateUser([
      'access content',
      'use text format basic_html',
    ]);
  }

  /**
   * Tests that the settings page can be reached and saved.
   */
  public function testSettingsPageExists(): void {
    $this->drupalLogin($this->user);
    $this->drupalGet($this->pageRoute);
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('Настоящие Положение является официальным документом');
  }

}
