<?php

declare(strict_types=1);

namespace Drupal\Tests\fz152\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests for the fz152 module.
 */
class Fz152SettingsFormTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'fz152',
  ];

  /**
   * The User used for the test.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * The User used for the test.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $user;

  /**
   * Settings form url.
   */
  protected Url $settingsRoute;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->settingsRoute = Url::fromRoute('fz152.settings');
    $this->user = $this->DrupalCreateUser();
    $this->adminUser = $this->DrupalCreateUser([
      'administer fz152',
    ]);
  }

  /**
   * Tests that the settings page can be reached and saved.
   */
  public function testSettingsPageExists(): void {
    $this->drupalLogin($this->user);
    $this->drupalGet($this->settingsRoute);
    $this->assertSession()->statusCodeEquals(403);

    $this->drupalLogin($this->adminUser);
    $this->drupalGet($this->settingsRoute);
    $this->assertSession()->statusCodeEquals(200);

    $edit = [
      'enable' => FALSE,
      'is_checkbox' => FALSE,
      'checkbox_title' => 'Test title',
      'checkbox_title_2' => 'Test title 2',
      'checkbox_title_3' => 'Test title 3',
      'checkbox_title_4' => 'Test title 4',
      'checkbox_title_5' => 'Test title 5',
      'checkbox_title_6' => 'Test title 6',
      'checkbox_title_7' => 'Test title 7',
      'checkbox_title_8' => 'Test title 8',
      'checkbox_title_9' => 'Test title 9',
      'checkbox_title_10' => 'Test title 10',
    ];
    $expected_values = [
      'enable' => FALSE,
      'is_checkbox' => FALSE,
      'checkbox_title' => 'Test title',
      'checkbox_title_2' => 'Test title 2',
      'checkbox_title_3' => 'Test title 3',
      'checkbox_title_4' => 'Test title 4',
      'checkbox_title_5' => 'Test title 5',
      'checkbox_title_6' => 'Test title 6',
      'checkbox_title_7' => 'Test title 7',
      'checkbox_title_8' => 'Test title 8',
      'checkbox_title_9' => 'Test title 9',
      'checkbox_title_10' => 'Test title 10',
    ];
    $this->submitForm($edit, 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    foreach ($expected_values as $field => $expected_value) {
      $actual_value = $this->config('fz152.settings')->get($field);
      $this->assertEquals($expected_value, $actual_value);
    }
  }

}
