<?php

declare(strict_types=1);

namespace Drupal\Tests\fz152\Functional;

// cspell:ignore Lorem ipsum dolor sit amet consectetur adipiscing elit Nullam
use Drupal\Core\Url;
use Drupal\filter\Entity\FilterFormat;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests for the fz152 module.
 */
class Fz152SettingsPageFormTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'fz152',
  ];

  /**
   * The User used for the test.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * The User used for the test.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $user;

  /**
   * Settings form url.
   */
  protected Url $settingsRoute;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->settingsRoute = Url::fromRoute('fz152.page_settings');
    $this->user = $this->DrupalCreateUser();
    $basic_html_format = FilterFormat::create([
      'format' => 'basic_html',
      'name' => 'Basic HTML',
      'filters' => [
        'filter_html' => [
          'status' => 1,
          'settings' => [
            'allowed_html' => '<p> <br> <strong> <a> <em>',
          ],
        ],
      ],
    ]);
    $basic_html_format->save();
    $this->adminUser = $this->DrupalCreateUser([
      'administer fz152',
      'use text format basic_html',
    ]);
  }

  /**
   * Tests that the settings page can be reached and saved.
   */
  public function testSettingsPageExists(): void {
    $this->drupalLogin($this->user);
    $this->drupalGet($this->settingsRoute);
    $this->assertSession()->statusCodeEquals(403);

    $this->drupalLogin($this->adminUser);
    $this->drupalGet($this->settingsRoute);
    $this->assertSession()->statusCodeEquals(200);

    $edit = [
      'enabled' => FALSE,
      'path' => '/policy',
      'title' => 'Test title',
      'text' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.',
    ];
    $expected_values = [
      'enable' => FALSE,
      'path' => '/policy',
      'title' => 'Test title',
      'text' => [
        'value' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.',
        'format' => 'basic_html',
      ],
    ];
    $this->submitForm($edit, 'Save configuration');
    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    foreach ($expected_values as $field => $expected_value) {
      $actual_value = $this->config('fz152.privacy_policy_page')->get($field);
      $this->assertEquals($expected_value, $actual_value);
    }
  }

}
